Welcome to Shape4D’s documentation! — Shape4D 0.08 documentation

The aims at predicting shadows of solar beam on windows/walls in building or on panels of solar cells/collectors, and we first defined some geometrical functions specific for the purpose.

- About Shape4D
  - Functions of Shape4D
- Installation
  - Preparation
  - Install the package
- Get started
  - Import Shape4D

- Point, line and polygon
  - Point
  - Line and plane
  - Segement
  - Polygon
- Predefined shapes
  - Convex polygon
  - Hollow four-sided polygon
  - Transformation to 3D space
- Point and plane
  - Point vs line
  - Point vs plane
- Line across line, plane and polygon
  - Line vs line
  - Line vs plane
  - Line vs polygon
- Precision control

# Memo

Welcome to any reply !

# Reference list

- Index

- Search Page